/******************************************************************************/
/* Mednafen Sony PS1 Emulation Module                                         */
/******************************************************************************/
/* debug.h:
**  Copyright (C) 2011-2016 Mednafen Team
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 2
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software Foundation, Inc.,
** 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

#ifndef __MDFN_PSX_DEBUG_H
#define __MDFN_PSX_DEBUG_H

#ifdef WANT_DEBUGGER

namespace MDFN_IEN_PSX
{

MDFN_HIDE extern DebuggerInfoStruct PSX_DBGInfo;

bool DBG_Init(void) MDFN_COLD;

void DBG_Break(void);

void DBG_GPUScanlineHook(unsigned scanline);

}

#endif

#endif
